*******************
Performance Testing
*******************

The ``benchmarks`` directory contains scripts for measuring the performance of arkouda, optionally compared to the (single-node) performance of NumPy.

Argsort
=======

.. argparse::
   :filename: ../benchmarks/argsort.py
   :func: create_parser
   :prog: argsort.py

Gather
=======

.. argparse::
   :filename: ../benchmarks/gather.py
   :func: create_parser
   :prog: gather.py

Reduce
======

.. argparse::
   :filename: ../benchmarks/reduce.py
   :func: create_parser
   :prog: reduce.py

Scan
====

.. argparse::
   :filename: ../benchmarks/scan.py
   :func: create_parser
   :prog: scan.py

Scatter
=======

.. argparse::
   :filename: ../benchmarks/scatter.py
   :func: create_parser
   :prog: scatter.py

Stream
======

.. argparse::
   :filename: ../benchmarks/stream.py
   :func: create_parser
   :prog: stream.py

 
